@@ -27,6 +27,7 @@ from .stream_helpers import (
 )
 from .environment.logging import setup_logger
 from . import constants
+from .image_codecs import RecognizedImageType
 
 
 class RejectionNoticeEnum(Enum):
@@ -251,6 +252,21 @@ class Toilmore(object):
         stream_factory = await stream_from_argument(image_arg)
         st = stream_factory()
         one_pass_info = await pass_and_compute_hash(st)
+        print(one_pass_info)
+        # This is not an accepted image input...
+        if not one_pass_info.image_type:
+            rn = RejectionNotice(
+                rejection_notice=RejectionNoticeEnum.HTTP_REQUEST_ERROR,
+                inner_error=RequestIssueException(
+                    'The image input is not allowed. We only accept: {}'.format(
+                        RecognizedImageType.list()
+                    )
+                )
+            )
+            return OptimizationResponse(
+                status=OptimizationResponseStatus.FAILURE,
+                rejection_notice=rn
+            )
 
         api_request = ApiRequest(
             one_pass_info=one_pass_info,
